@@ -795,3 +795,14 @@ For more detailed information, you can try the `executor-normalizer` locally to
 '''
 
     return (msg, original_msg)
+
+
+def get_tag_from_dist_info_path(path: Path) -> str:
+    """Get tag from stem of path.
+
+    :param path: the path of the executor
+    :return: str
+    """
+
+    stem = path.stem
+    return stem.replace(r'.dist-info', '') if stem else None
